/***************************************************************************
                          ann_w_triv.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_w_triv.h>

  //              //
 // class W_triv //
//              //

ANN::W_triv::~W_triv()
{
}

void
ANN::W_triv::feed_back(const Term &d_)
{
  size_t i, l=w.get_size();
  for (i=0; i<l; ++i) w.get_data()[i]=d_.get_data()[i];
}

void
ANN::W_triv::commit(NE &ne)
{
}

